@@ -38,7 +38,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw($select_fullautoapi_setup);
 
 use Net::FullAuto::Cloud::fa_amazon;
-use Net::FullAuto::FA_Core qw[cmd_raw $localhost];
+use Net::FullAuto::FA_Core qw[$localhost];
 use File::HomeDir;
 my $home_dir=File::HomeDir->my_home.'/';
 my $username=getlogin || getpwuid($<);
@@ -390,7 +390,7 @@ if ($do==1) {
    ($stdout,$stderr)=$handle->cmd("rm -rvf $zmq",'__display__');
    $zmq=~s/\.tar\.gz$//;
    ($stdout,$stderr)=$handle->cwd($zmq);
-   cmd_raw($handle,'export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig');
+   $handle->cmd_raw('export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig');
    ($stdout,$stderr)=$handle->cmd('./configure','__display__');
    if ($^O eq 'cygwin') {
       my $ad="        -no-undefined \\%NL%".
@@ -475,15 +475,14 @@ print "DOING NGINX\n";
    ($stdout,$stderr)=$handle->cmd("make install",'__display__');
    ($stdout,$stderr)=$handle->cmd("sed -i 's/1024/64/' ".
       "/usr/local/nginx/nginx.conf");
-   $ad="%NL%".
-       "%NL%            include fastcgi_params;".
-       "%NL%            fastcgi_pass  localhost:3003;%NL%%NL%";
+   $ad="            include fastcgi_params;%NL%".
+       "            fastcgi_pass localhost:3003;";
    $ad=<<END;
-sed -i '1,/location/ {/location/a\
+sed -i '1,/location/ {/location/a\\\
 $ad
 }' /usr/local/nginx/nginx.conf
 END
-   ($stdout,$stderr)=$handle->cmd($ad);
+   $handle->cmd_raw($ad);
    $ad='%NL%        location /static {'.
        '%NL%            root /home/Administrator/FullAutoAPI/root;'.
        '%NL%        }%NL%%NL%';
@@ -607,7 +606,7 @@ exit;
 ########################################
 END
       print $show;
-      cmd_raw($handle,
+      $handle->cmd_raw(
          'perl -MCPAN -e \'CPAN::Shell->notest('.
          '"install","Starman")\'',
          '__display__');
@@ -619,7 +618,7 @@ END
 ########################################
 END
       print $show;
-      cmd_raw($handle,
+      $handle->cmd_raw(
          'perl -MCPAN -e \'CPAN::Shell->notest('.
          '"install","HTTP::Server::Simple")\'',
          '__display__');
@@ -632,7 +631,7 @@ END
 ########################################
 END
       print $show;
-      cmd_raw($handle,
+      $handle->cmd_raw(
          'perl -MCPAN -e \'CPAN::Shell->notest('.
          '"install","Perl::Critic")\'',
          '__display__');
@@ -644,7 +643,7 @@ END
 ########################################
 END
    #print $show;
-   #cmd_raw($handle,
+   #$handle->cmd_raw(
    #   'sudo perl -MCPAN -e \'CPAN::Shell->force('.
    #   '"install","ExtUtils::Embed")\'',
    #   '__display__');
@@ -797,14 +796,14 @@ END
          sleep 10;
       }
       unless ($^O eq 'cygwin') {
-         cmd_raw($handle,
+         $handle->cmd_raw(
             "${sudo}LD_LIBRARY_PATH=/usr/local/lib ".
             "PKG_CONFIG_PATH=/usr/local/lib/pkgconfig ".
             "LD_PRELOAD=/usr/local/lib/libzmq.so.5 ".
             "cpan -f -i $module",
             '__display__');
       } else {
-         cmd_raw($handle,"cpan -i $module",
+         $handle->cmd_raw("cpan -i $module",
             '__display__');
       }
    }
@@ -816,7 +815,7 @@ END
 ########################################
 END
 #   print $show;
-#   cmd_raw($handle,
+#   $handle->cmd_raw(
 #      'sudo perl -MCPAN -e \'CPAN::Shell->force('.
 #      '"install","Regexp::Assemble")\'',
 #      '__display__');
@@ -854,7 +853,7 @@ END
 
 ########################################
 END
-   cmd_raw($handle,"${sudo}cpan Catalyst::Controller::HTML::FormFu",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Controller::HTML::FormFu",
       '__display__');
    print "\n";
    $show=<<END;
@@ -865,7 +864,7 @@ END
 
 ########################################
 END
-   cmd_raw($handle,"${sudo}cpan CatalystX::OAuth2",
+   $handle->cmd_raw("${sudo}cpan CatalystX::OAuth2",
       '__display__');
    print "\n";
    $show=<<END;
@@ -878,7 +877,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Task::Catalyst::Tutorial",'__display__');
+   $handle->cmd_raw("${sudo}cpan Task::Catalyst::Tutorial",'__display__');
    $show=<<END;
 
 ########################################
@@ -887,7 +886,7 @@ END
 
 ########################################
 END
-   cmd_raw($handle,
+   $handle->cmd_raw(
       'perl -MCPAN -e \'CPAN::Shell->notest('.
       '"install","DBIx::Class")\'',
       '__display__');
@@ -899,7 +898,7 @@ END
 
 ########################################
 END
-   cmd_raw($handle,"${sudo}cpan DBIx::Class::Schema::Loader",
+   $handle->cmd_raw("${sudo}cpan DBIx::Class::Schema::Loader",
       '__display__');
 #   $show=<<END;
 #
@@ -932,7 +931,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan YAML::Syck",'__display__');
+   $handle->cmd_raw("${sudo}cpan YAML::Syck",'__display__');
    $show=<<END;
 
 ########################################
@@ -943,7 +942,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Controller::REST",'__display__');
+   $handle->cmd_raw("${sudo}cpan Catalyst::Controller::REST",'__display__');
    $show=<<END;
 
 ########################################
@@ -954,7 +953,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Model::Adaptor",'__display__');
+   $handle->cmd_raw("${sudo}cpan Catalyst::Model::Adaptor",'__display__');
    $show=<<END;
 
 ########################################
@@ -965,7 +964,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::View::JSON",'__display__');
+   $handle->cmd_raw("${sudo}cpan Catalyst::View::JSON",'__display__');
    $show=<<END;
 
 ########################################
@@ -976,7 +975,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::View::TT::Alloy",'__display__');
+   $handle->cmd_raw("${sudo}cpan Catalyst::View::TT::Alloy",'__display__');
    $show=<<END;
 
 ########################################
@@ -987,7 +986,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Unicode",'__display__');
+   $handle->cmd_raw("${sudo}cpan Catalyst::Plugin::Unicode",'__display__');
    $show=<<END;
 
 ########################################
@@ -998,7 +997,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan DBIx::Class::PassphraseColumn",'__display__');
+   $handle->cmd_raw("${sudo}cpan DBIx::Class::PassphraseColumn",'__display__');
    $show=<<END;
 
 ########################################
@@ -1009,7 +1008,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Authen::Passphrase::BlowfishCrypt",
+   $handle->cmd_raw("${sudo}cpan Authen::Passphrase::BlowfishCrypt",
            '__display__');
    $show=<<END;
 
@@ -1021,7 +1020,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Method::Signatures::Simple",
+   $handle->cmd_raw("${sudo}cpan Method::Signatures::Simple",
            '__display__');
    $show=<<END;
 
@@ -1033,7 +1032,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan HTML::FormHandler",
+   $handle->cmd_raw("${sudo}cpan HTML::FormHandler",
            '__display__');
    $show=<<END;
 
@@ -1045,7 +1044,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan HTML::FormHandler::Model::DBIC",
+   $handle->cmd_raw("${sudo}cpan HTML::FormHandler::Model::DBIC",
            '__display__');
    $show=<<END;
 
@@ -1057,7 +1056,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan CatalystX::SimpleLogin",'__display__');
+   $handle->cmd_raw("${sudo}cpan CatalystX::SimpleLogin",'__display__');
    $show=<<END;
 
 ########################################
@@ -1068,7 +1067,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session",'__display__');
+   $handle->cmd_raw("${sudo}cpan Catalyst::Plugin::Session",'__display__');
    $show=<<END;
 
 ########################################
@@ -1080,7 +1079,7 @@ END
    print $show;
    sleep 1;
    # http://vasil9v.tumblr.com/post/31921755331/compiling-memcached-on-cygwinwindows
-   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session::Store::Memcached",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Plugin::Session::Store::Memcached",
            '__display__');
    $show=<<END;
 
@@ -1092,7 +1091,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session::State::Cookie",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Plugin::Session::State::Cookie",
            '__display__');
    $show=<<END;
 
@@ -1104,7 +1103,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Authentication",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Plugin::Authentication",
            '__display__');
    $show=<<END;
 
@@ -1116,7 +1115,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Authentication::Store::DBIx::Class",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Authentication::Store::DBIx::Class",
            '__display__');
    $show=<<END;
 
@@ -1128,7 +1127,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Authorization::Roles",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Plugin::Authorization::Roles",
            '__display__');
    $show=<<END;
 
@@ -1140,7 +1139,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan DBIx::Class::TimeStamp",
+   $handle->cmd_raw("${sudo}cpan DBIx::Class::TimeStamp",
            '__display__');
    $show=<<END;
 
@@ -1152,7 +1151,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Controller::ACL",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Controller::ACL",
            '__display__');
    $show=<<END;
 
@@ -1164,7 +1163,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan FCGI",
+   $handle->cmd_raw("${sudo}cpan FCGI",
            '__display__');
    $show=<<END;
 
@@ -1176,7 +1175,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan FCGI::ProcManager",
+   $handle->cmd_raw("${sudo}cpan FCGI::ProcManager",
            '__display__');
    $show=<<END;
 
@@ -1188,7 +1187,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::Helper::Model::DBIC::Schema",
+   $handle->cmd_raw("${sudo}cpan Catalyst::Helper::Model::DBIC::Schema",
            '__display__');
    $show=<<END;
 
@@ -1200,7 +1199,7 @@ END
 END
    print $show;
    sleep 1;
-   cmd_raw($handle,"${sudo}cpan Catalyst::View::Email",
+   $handle->cmd_raw("${sudo}cpan Catalyst::View::Email",
            '__display__');
    $show=<<END;
 
@@ -1268,9 +1267,9 @@ END
        "    },";
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i '/Send X-Catalyst header/a$ad' $pm_path");
-   cmd_raw($handle,
+   $handle->cmd_raw(
        "${sudo}sed -i 's/\\(^Session$\\\)/    \\1/' $pm_path");
-   cmd_raw($handle,
+   $handle->cmd_raw(
        "${sudo}sed -i 's/\\(^authentication =.*\\\)/    \\1/' $pm_path");
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pm_path");
@@ -1521,9 +1520,11 @@ END
    my $view_path='./lib/FullAutoAPI/View/TT.pm';
    ($stdout,$stderr)=$handle->cmd(
       "./script/fullautoapi_create.pl view TT TT",'__display__');
-   $ad='    WRAPPER => %SQ%wrapper.tt%SQ%,%NL%';
+   $ad='WRAPPER => %SQ%wrapper.tt%SQ%,';
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/render_die/a$ad\' $view_path");
+   $handle->cmd_raw(
+       "${sudo}sed -i 's/\\(^WRAPPER =.*\\\)/    \\1/' $view_path");
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $view_path");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $view_path");
